@@ -1,8 +1,8 @@
-__title__ = 'Amino_new.py'
+__title__ = 'Amino.py'
 __author__ = 'Slimakoi'
 __license__ = 'MIT'
 __copyright__ = 'Copyright 2020-2021 Slimakoi'
-__version__ = '4.4'
+__version__ = '4.6'
 
 from .acm import ACM
 from .client import Client
@@ -12,7 +12,7 @@ from .lib.util import device, exceptions, headers, helpers, objects
 from requests import get
 from json import loads
 
-__newest__ = loads(get("https://pypi.python.org/pypi/Amino-new.py/json").text)["info"]["version"]
+__newest__ = loads(get("https://pypi.org/project/Amino-new.py/json").text)["info"]["version"]
 
 if __version__ != __newest__:
     print(exceptions.LibraryUpdateAvailable(f"New version of {__title__} available: {__newest__} (Using {__version__})"))
